pub struct NodeUpdateError {
pub is_receive_queue_full: bool,
pub is_transit_queue_full: bool,
}Expand description
Error that can be returned by Node update method.
Fields
is_receive_queue_full: boolWhether the received packet queue is full, meaning that a packet addressed to this node could not be stored.
is_transit_queue_full: boolWhether the transit queue is full, meaning that a packet addressed to another node could not be scheduled for forwarding.