Packet

Struct Packet 

pub struct Packet {
    pub source_device_identifier: u8,
    pub id: IdType,
    pub data: PacketDataBytes,
    /* private fields */
}

Fields

source_device_identifier: u8id: IdTypedata: PacketDataBytes

Implementations

Source

impl Packet

pub fn is_checksum_correct(&self) -> bool

Checks if the calculated checksum of the packet matches to the already stored one.

pub fn summarized(self) -> Packet

Calculates checksum for this packet, and sets calculated value into .checksum field. returns new summarized packet.

Source

impl Packet

pub fn get_id(&self) -> IdType

pub fn set_id(&mut self, id: IdType)

pub fn increment_id(&mut self)

Source

impl Packet

Source

impl Packet

pub fn deacrease_lifetime(self) -> Result<Self, PacketLifetimeEnded>

Source

impl Packet

pub fn mutated(self) -> Result<Self, RespondToBroadcastAddressError>

Source

impl Packet

pub fn get_spec_state(&self) -> PacketState

pub fn set_spec_state(&mut self, new_state: PacketState)

Source

impl Packet

pub fn new( source_device_identifier: u8, destination_device_identifier: u8, id: IdType, lifetime: LifeTimeType, spec_state: PacketState, ignore_duplications_flag: bool, data: PacketDataBytes, ) -> Packet

pub fn has_correct_source_device_identifier(&self) -> bool

pub const fn size_of_bytes() -> usize