pub struct Packet {
pub source_device_identifier: u8,
pub id: IdType,
pub data: PacketDataBytes,
/* private fields */
}Fields
source_device_identifier: u8id: IdTypedata: PacketDataBytesImplementations
Sourceimpl Packet
impl Packet
Sourcepub fn is_checksum_correct(&self) -> bool
pub fn is_checksum_correct(&self) -> bool
Checks if the calculated checksum of the packet matches to the already stored one.
Sourcepub fn summarized(self) -> Packet
pub fn summarized(self) -> Packet
Calculates checksum for this packet, and sets calculated value into .checksum field. returns new summarized packet.
Sourceimpl Packet
impl Packet
pub fn is_destination_reached(&self, identifier: GeneralAddressType) -> bool
Sourceimpl Packet
impl Packet
pub fn get_spec_state(&self) -> PacketState
pub fn set_spec_state(&mut self, new_state: PacketState)
Sourceimpl Packet
impl Packet
pub fn new( source_device_identifier: u8, destination_device_identifier: u8, id: IdType, lifetime: LifeTimeType, spec_state: PacketState, ignore_duplications_flag: bool, data: PacketDataBytes, ) -> Packet
pub fn has_correct_source_device_identifier(&self) -> bool
pub const fn size_of_bytes() -> usize